@@ -31,8 +31,16 @@ class ViewController:
         """
         self.__signals_ids = {}
         self.__type = controller_type
-        self.connect("map", self.__on_map)
-        self.connect("unmap", self.__on_unmap)
+        self.connect("destroy", self.__on_destroy)
+        self.__signals_ids[
+            App().player.connect("current-changed",
+                                 self._on_current_changed)] = App().player
+        self.__signals_ids[
+            App().player.connect("duration-changed",
+                                 self._on_duration_changed)] = App().player
+        self.__signals_ids[
+            App().art.connect("%s-artwork-changed" % self.__type,
+                              self._on_artwork_changed)] = App().art
 
 #######################
 # PROTECTED           #
@@ -43,22 +51,13 @@ class ViewController:
     def _on_artwork_changed(self, artwork, *args):
         pass
 
+    def _on_duration_changed(self, player, track_id):
+        pass
+
 #######################
 # PRIVATE             #
 #######################
-    def __on_map(self, widget):
-        """
-            Connect signals
-            @param widget as Gtk.Widget
-        """
-        self.__signals_ids[
-            App().player.connect("current-changed",
-                                 self._on_current_changed)] = App().player
-        self.__signals_ids[
-            App().art.connect("%s-artwork-changed" % self.__type,
-                              self._on_artwork_changed)] = App().art
-
-    def __on_unmap(self, widget):
+    def __on_destroy(self, widget):
         """
             Disconnect signals
             @param widget as Gtk.Widget
