@@ -10,15 +10,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GObject
+from gi.repository import Gtk, GObject, GLib
 
 from lollypop.helper_art import ArtHelperEffect
 from lollypop.controller_information import InformationController
 from lollypop.controller_progress import ProgressController
 from lollypop.controller_playback import PlaybackController
-from lollypop.widgets_cover import CoverWidget
 from lollypop.utils import on_realize
-from lollypop.define import App, ArtSize
+from lollypop.define import App, ArtSize, Type
 
 
 class MiniPlayer(Gtk.Bin, InformationController,
@@ -30,22 +29,24 @@ class MiniPlayer(Gtk.Bin, InformationController,
         "revealed": (GObject.SignalFlags.RUN_FIRST, None, (bool,)),
     }
 
-    def __init__(self, width):
+    def __init__(self):
         """
             Init mini player
-            @param width as int
         """
-        self.__width = width
-        self.__height = 0
-        self.__cover_widget = None
+        self.__size = 0
+        self.__allocation_timeout_id = None
+        self.__cover = None
         Gtk.Bin.__init__(self)
-        InformationController.__init__(self, False, ArtHelperEffect.BLUR_HARD)
+        InformationController.__init__(self, False,
+                                       ArtHelperEffect.BLUR_HARD |
+                                       ArtHelperEffect.DARKER)
         ProgressController.__init__(self)
         PlaybackController.__init__(self)
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/MiniPlayer.ui")
         builder.connect_signals(self)
 
+        self.get_style_context().add_class("black")
         self.__grid = builder.get_object("grid")
         self.__revealer = builder.get_object("revealer")
         self.__revealer_box = builder.get_object("revealer_box")
@@ -74,43 +75,48 @@ class MiniPlayer(Gtk.Bin, InformationController,
                                                  self.__on_current_changed)
         self.__signal_id2 = App().player.connect("status-changed",
                                                  self.__on_status_changed)
-        self.__signal_id3 = App().player.connect("lock-changed",
-                                                 self.__on_lock_changed)
+        self.__signal_id3 = App().player.connect("duration-changed",
+                                                 self.on_duration_changed)
         self.__on_current_changed(App().player)
         if App().player.current_track.id is not None:
             PlaybackController.on_status_changed(self, App().player)
             self.update_position()
             ProgressController.on_status_changed(self, App().player)
         self.add(builder.get_object("widget"))
+        self.connect("size-allocate", self.__on_size_allocate)
         self.connect("destroy", self.__on_destroy)
 
-    def update_cover(self, width):
-        """
-            Update cover for width
-            @param width as int
-        """
-        if self.__width == width:
-            return
-        self.__width = width
-        InformationController.on_current_changed(self, width, None)
-
     def do_get_preferred_width(self):
         """
             Force preferred width
         """
         (min, nat) = Gtk.Bin.do_get_preferred_width(self)
         # Allow resizing
-        return (0, 0)
+        return (0, nat)
 
     def do_get_preferred_height(self):
         """
             Force preferred height
         """
-        return self.__grid.get_preferred_height()
+        (min, nat) = self.__grid.get_preferred_height()
+        return (min, min)
 
 #######################
 # PROTECTED           #
 #######################
+    def _on_album_artwork(self, surface):
+        """
+            Set album artwork
+            @param surface as str
+        """
+        if surface is None:
+            self.__grid.get_style_context().add_class("black")
+            self._artwork.get_style_context().add_class("black")
+        else:
+            InformationController._on_album_artwork(self, surface)
+            self.__grid.get_style_context().remove_class("black")
+            self._artwork.get_style_context().remove_class("black")
+
     def _on_lyrics_button_clicked(self, button):
         """
             Show lyrics view
@@ -127,15 +133,20 @@ class MiniPlayer(Gtk.Bin, InformationController,
         if self.__revealer.get_reveal_child():
             self.__revealer.set_reveal_child(False)
             self.emit("revealed", False)
-            if self.__cover_widget is not None:
-                self.__cover_widget.destroy()
-                self.__cover_widget = None
+            if self.__cover is not None:
+                self.__cover.destroy()
+                self.__cover = None
         else:
-            if self.__cover_widget is None:
-                self.__cover_widget = CoverWidget(False, ArtSize.BIG)
-                self.__cover_widget.update(App().player.current_track.album)
-                self.__cover_widget.show()
-                self.__revealer_box.pack_start(self.__cover_widget,
+            if self.__cover is None:
+                self.__cover = App().art_helper.get_image(
+                                                        ArtSize.BIG,
+                                                        ArtSize.BIG,
+                                                        "small-cover-frame")
+                self.__cover.set_property("halign", Gtk.Align.CENTER)
+                self.__cover.set_property("valign", Gtk.Align.CENTER)
+                self.__update_artwork()
+                self.__cover.show()
+                self.__revealer_box.pack_start(self.__cover,
                                                True, True, 0)
             self.__revealer.set_reveal_child(True)
             self.emit("revealed", True)
@@ -143,6 +154,46 @@ class MiniPlayer(Gtk.Bin, InformationController,
 #######################
 # PRIVATE             #
 #######################
+    def __update_artwork(self):
+        """
+            Update artwork based on current track
+        """
+        if App().player.current_track.id == Type.RADIOS:
+            App().art_helper.set_radio_artwork(
+                App().player.current_track.radio_name,
+                ArtSize.BIG,
+                ArtSize.BIG,
+                self._artwork.get_scale_factor(),
+                self.__on_artwork,
+                ArtHelperEffect.NONE)
+        else:
+            App().art_helper.set_album_artwork(
+                App().player.current_track.album,
+                ArtSize.BIG,
+                ArtSize.BIG,
+                self._artwork.get_scale_factor(),
+                self.__on_artwork,
+                ArtHelperEffect.NONE)
+
+    def __handle_size_allocate(self, allocation):
+        """
+            Change box max/min children
+            @param allocation as Gtk.Allocation
+        """
+        self.__allocation_timeout_id = None
+        # We use parent height because we may be collapsed
+        parent = self.get_parent()
+        if parent is None:
+            height = allocation.height
+        else:
+            height = parent.get_allocated_height()
+        new_size = max(allocation.width, height)
+        if new_size == 1 or self.__size == new_size:
+            return
+        self.__size = new_size
+        self._previous_artwork_id = None
+        InformationController.on_current_changed(self, new_size, None)
+
     def __on_destroy(self, widget):
         """
             Handle widget cleanup
@@ -160,11 +211,11 @@ class MiniPlayer(Gtk.Bin, InformationController,
         """
         if App().player.current_track.id is not None:
             self.show()
-        InformationController.on_current_changed(self, self.__width, None)
+        InformationController.on_current_changed(self, self.__size, None)
         ProgressController.on_current_changed(self, player)
         PlaybackController.on_current_changed(self, player)
-        if self.__cover_widget is not None:
-            self.__cover_widget.update(App().player.current_track.album)
+        if self.__cover is not None:
+            self.__update_artwork()
 
     def __on_status_changed(self, player):
         """
@@ -174,10 +225,30 @@ class MiniPlayer(Gtk.Bin, InformationController,
         ProgressController.on_status_changed(self, player)
         PlaybackController.on_status_changed(self, player)
 
-    def __on_lock_changed(self, player):
+    def __on_size_allocate(self, widget, allocation):
         """
-            Lock toolbar
-            @param player as Player
+            Delayed handling
+            @param widget as Gtk.Widget
+            @param allocation as Gtk.Allocation
         """
-        self._prev_button.set_sensitive(not player.is_locked)
-        self._next_button.set_sensitive(not player.is_locked)
+        if self.__allocation_timeout_id is not None:
+            GLib.source_remove(self.__allocation_timeout_id)
+        self.__allocation_timeout_id = GLib.idle_add(
+            self.__handle_size_allocate, allocation)
+
+    def __on_artwork(self, surface):
+        """
+            Set artwork
+            @param surface as str
+        """
+        if surface is None:
+            self.__cover.get_style_context().add_class("white")
+            if App().player.current_track.id == Type.RADIOS:
+                icon_name = "audio-input-microphone-symbolic"
+            else:
+                icon_name = "folder-music-symbolic"
+            self.__cover.set_from_icon_name(icon_name,
+                                            Gtk.IconSize.DIALOG)
+        else:
+            self.__cover.get_style_context().remove_class("white")
+            self.__cover.set_from_surface(surface)
