@@ -13,7 +13,6 @@
 from gi.repository import Gtk
 
 from lollypop.define import App
-from lollypop.view_search import SearchView
 
 
 class SearchPopover(Gtk.Popover):
@@ -27,17 +26,19 @@ class SearchPopover(Gtk.Popover):
         """
         Gtk.Popover.__init__(self)
         self.__width = 0
+        self.__search = ""
         self.set_position(Gtk.PositionType.BOTTOM)
         self.connect("map", self.__on_map)
-        search_view = SearchView()
-        search_view.show()
-        self.add(search_view)
+        self.connect("unmap", self.__on_unmap)
 
-    def set_text(self, text):
+    def set_search(self, search):
         """
             Set search text
+            @param search as str
         """
-        self.__entry.set_text(text)
+        self.__search = search
+        if self.get_child() is not None:
+            self.get_child().set_search(search)
 
     def do_get_preferred_width(self):
         if self.__width == 0:
@@ -57,7 +58,21 @@ class SearchPopover(Gtk.Popover):
             Set popover size
             @param widget as Gtk.Widget
         """
+        search_view = App().window.container.get_view_search(self.__search)
+        search_view.show()
+        if search_view in App().window.container.stack.get_children():
+            App().window.container.stack.remove(search_view)
+        self.add(search_view)
         window_size = App().window.get_size()
         height = window_size[1]
         self.__width = min(500, window_size[0])
         self.set_size_request(self.__width, height * 0.7)
+
+    def __on_unmap(self, widget):
+        """
+            Move widget inside container
+        """
+        search_view = self.get_child()
+        search_view.hide()
+        self.remove(search_view)
+        App().window.container.stack.add(search_view)
