@@ -15,7 +15,8 @@ from gi.repository import Gtk, Gio, GLib
 from gettext import gettext as _
 
 from lollypop.pop_next import NextPopover
-from lollypop.define import App, Shuffle, NextContext, Type
+from lollypop.pop_appmenu import AppMenuPopover
+from lollypop.define import App, Shuffle, Repeat, Type
 
 
 class ToolbarEnd(Gtk.Bin):
@@ -33,7 +34,6 @@ class ToolbarEnd(Gtk.Bin):
         self.__timeout_id = None
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarEnd.ui")
-        builder.connect_signals(self)
 
         self.__party_submenu = builder.get_object("party_submenu")
         self.add(builder.get_object("end"))
@@ -47,15 +47,15 @@ class ToolbarEnd(Gtk.Bin):
         self.__shuffle_action.set_state(App().settings.get_value("shuffle"))
         self.__shuffle_action.connect("change-state",
                                       self.__on_shuffle_change_state)
-        self.__playback_action = Gio.SimpleAction.new_stateful(
-            "playback",
+        self.__repeat_action = Gio.SimpleAction.new_stateful(
+            "repeat",
             GLib.VariantType.new("s"),
             GLib.Variant("s", "none"))
-        self.__playback_action.set_state(App().settings.get_value("playback"))
-        self.__playback_action.connect("change-state",
-                                       self.__on_playback_change_state)
+        self.__repeat_action.set_state(App().settings.get_value("repeat"))
+        self.__repeat_action.connect("change-state",
+                                     self.__on_repeat_change_state)
         App().add_action(self.__shuffle_action)
-        App().add_action(self.__playback_action)
+        App().add_action(self.__repeat_action)
 
         self.__shuffle_button = builder.get_object("shuffle-button")
         self.__shuffle_image = builder.get_object("shuffle-button-image")
@@ -64,8 +64,8 @@ class ToolbarEnd(Gtk.Bin):
                                       self.__on_shuffle_button_activate)
         App().add_action(shuffle_button_action)
         App().set_accels_for_action("app.shuffle-button", ["<Control>r"])
-        App().settings.connect("changed::shuffle", self.__on_playback_changed)
-        App().settings.connect("changed::playback", self.__on_playback_changed)
+        App().settings.connect("changed::shuffle", self.__on_repeat_changed)
+        App().settings.connect("changed::repeat", self.__on_repeat_changed)
 
         party_action = Gio.SimpleAction.new_stateful(
             "party",
@@ -88,16 +88,12 @@ class ToolbarEnd(Gtk.Bin):
         self.__next_popover = NextPopover()
         self.__next_popover.set_relative_to(self.__shuffle_button)
 
-        search_action = Gio.SimpleAction.new("search", None)
+        search_action = Gio.SimpleAction.new("search",
+                                             GLib.VariantType.new("s"))
         self.__search_button = builder.get_object("search-button")
         search_action.connect("activate", self.__on_search_activate)
         App().add_action(search_action)
-        App().set_accels_for_action("app.search", ["<Control>f"])
-
-        builder_menu = Gtk.Builder()
-        builder_menu.add_from_resource("/org/gnome/Lollypop/Appmenu.ui")
-        builder.get_object("settings-button").set_menu_model(
-            builder_menu.get_object("app-menu"))
+        App().set_accels_for_action("app.search('')", ["<Control>f"])
 
         self.__list_button = builder.get_object("list-button")
         self.__list_button.set_property("has-tooltip", True)
@@ -106,6 +102,7 @@ class ToolbarEnd(Gtk.Bin):
         self.__home_button = builder.get_object("home-button")
         App().player.connect("playlist-changed", self.__on_playlist_changed)
         self.__set_shuffle_icon()
+        builder.connect_signals(self)
 
     def on_next_changed(self, player):
         """
@@ -142,6 +139,14 @@ class ToolbarEnd(Gtk.Bin):
         self.__on_search_button_cancelled()
         self.__search_popover.set_text(search)
 
+    @property
+    def home_button(self):
+        """
+            Get home button
+            @return Gtk.Button
+        """
+        return self.__home_button
+
     @property
     def next_popover(self):
         """
@@ -218,6 +223,10 @@ class ToolbarEnd(Gtk.Bin):
            @param button as Gtk.MenuButton
         """
         if button.get_active():
+            popover = AppMenuPopover()
+            popover.set_relative_to(button)
+            popover.connect("closed", self.__on_popover_closed, button)
+            popover.popup()
             self.__next_popover.hide()
             self.__next_popover.inhibit(True)
         else:
@@ -299,15 +308,15 @@ class ToolbarEnd(Gtk.Bin):
             Set shuffle icon
         """
         shuffle = App().settings.get_enum("shuffle")
-        repeat = App().settings.get_enum("playback")
-        if repeat == NextContext.REPEAT_TRACK:
+        repeat = App().settings.get_enum("repeat")
+        if repeat == Repeat.TRACK:
             self.__shuffle_image.get_style_context().remove_class("selected")
             self.__shuffle_image.set_from_icon_name(
                 "media-playlist-repeat-song-symbolic",
                 Gtk.IconSize.SMALL_TOOLBAR)
         elif shuffle == Shuffle.NONE:
             self.__shuffle_image.get_style_context().remove_class("selected")
-            if repeat == NextContext.NONE:
+            if repeat == Repeat.ALL:
                 self.__shuffle_image.set_from_icon_name(
                     "media-playlist-repeat-symbolic",
                     Gtk.IconSize.SMALL_TOOLBAR)
@@ -338,7 +347,7 @@ class ToolbarEnd(Gtk.Bin):
         App().player.set_party(value.get_boolean())
         action.set_state(value)
         self.__shuffle_action.set_enabled(not value)
-        self.__playback_action.set_enabled(not value)
+        self.__repeat_action.set_enabled(not value)
         self.on_next_changed(App().player)
 
     def __on_scrobbling_mode_change_state(self, action, value):
@@ -360,13 +369,13 @@ class ToolbarEnd(Gtk.Bin):
         App().settings.set_value("shuffle", value)
         action.set_state(value)
 
-    def __on_playback_change_state(self, action, value):
+    def __on_repeat_change_state(self, action, value):
         """
             Update playback setting
             @param action as Gio.SimpleAction
-            @param value as bool
+            @param value as GLib.Variant
         """
-        App().settings.set_value("playback", value)
+        App().settings.set_value("repeat", value)
         action.set_state(value)
 
     def __on_shuffle_button_activate(self, action, param):
@@ -378,7 +387,7 @@ class ToolbarEnd(Gtk.Bin):
         self.__shuffle_button.set_active(
             not self.__shuffle_button.get_active())
 
-    def __on_playback_changed(self, settings, value):
+    def __on_repeat_changed(self, settings, value):
         """
             Update shuffle icon
             @param settings as Gio.Settings
@@ -403,11 +412,13 @@ class ToolbarEnd(Gtk.Bin):
             @param action as Gio.SimpleAction
             @param variant as GLib.Variant
         """
+        search = variant.get_string()
         if self.__search_button.get_visible():
             self.__search_button.set_active(
                 not self.__search_button.get_active())
+            self.__search_popover.set_search(search)
         else:
-            App().window.container.show_view(Type.SEARCH)
+            App().window.container.show_view(Type.SEARCH, search)
 
     def __on_list_button_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
