@@ -85,8 +85,10 @@ class DeviceManagerWidget(Gtk.Bin):
             @param selected_ids as [int]
         """
         self.__model.clear()
+        if not selected_ids:
+            return
         if selected_ids[0] == Type.PLAYLISTS:
-            playlists = [(Type.LOVED, App().playlists.LOVED)]
+            playlists = [(Type.LOVED, _("Loved tracks"))]
             playlists += App().playlists.get()
             synced_ids = App().playlists.get_synced_ids()
             self.__append_playlists(playlists, synced_ids)
